@@ -1,11 +1,9 @@
 __all__ = [
     'request_builder_tests',
-    'callables',
-    'models',
     'base',
-    'files',
     'response_handler_tests',
     'utility_tests',
-    'authentications',
-    'exceptions'
+    'mocks',
+    'api_call_tests',
+    'api_logger_tests'
 ]
\ No newline at end of file
